@@ -1,5 +1,6 @@
 var group__spa__pod =
 [
+    [ "body.h", "body_8h.html", null ],
     [ "builder.h", "builder_8h.html", null ],
     [ "command.h", "pod_2command_8h.html", null ],
     [ "compare.h", "compare_8h.html", null ],
@@ -8,7 +9,14 @@ var group__spa__pod =
     [ "iter.h", "iter_8h.html", null ],
     [ "parser.h", "parser_8h.html", null ],
     [ "pod.h", "pod_2pod_8h.html", null ],
+    [ "simplify.h", "simplify_8h.html", null ],
     [ "vararg.h", "vararg_8h.html", null ],
+    [ "spa_pod_frame", "structspa__pod__frame.html", [
+      [ "pod", "structspa__pod__frame.html#a33639010072a6ae1c60f0abb559d0197", null ],
+      [ "parent", "structspa__pod__frame.html#a51486db1e9f9e886bc0b0858321f1252", null ],
+      [ "offset", "structspa__pod__frame.html#a3af1eba573563e63ed9d5fa9b3246795", null ],
+      [ "flags", "structspa__pod__frame.html#aedaebc9933fd5e625c622c3a0f1f2d64", null ]
+    ] ],
     [ "spa_pod_builder_state", "structspa__pod__builder__state.html", [
       [ "offset", "structspa__pod__builder__state.html#ac64c9a0aad0f5630c44c86e97561ffae", null ],
       [ "flags", "structspa__pod__builder__state.html#a9406fb7fd6f0ea3cc9e99c9be6d76661", null ],
@@ -39,12 +47,6 @@ var group__spa__pod =
       [ "pod", "structspa__event.html#a2411141eed88d3587687a8d86c99d488", null ],
       [ "body", "structspa__event.html#a1cfdf789b23f6f0ba623f3fc973951bb", null ]
     ] ],
-    [ "spa_pod_frame", "structspa__pod__frame.html", [
-      [ "pod", "structspa__pod__frame.html#a33639010072a6ae1c60f0abb559d0197", null ],
-      [ "parent", "structspa__pod__frame.html#a51486db1e9f9e886bc0b0858321f1252", null ],
-      [ "offset", "structspa__pod__frame.html#a3af1eba573563e63ed9d5fa9b3246795", null ],
-      [ "flags", "structspa__pod__frame.html#aedaebc9933fd5e625c622c3a0f1f2d64", null ]
-    ] ],
     [ "spa_pod_parser_state", "structspa__pod__parser__state.html", [
       [ "offset", "structspa__pod__parser__state.html#a7d20db21de9472df961d8b2da5845ea0", null ],
       [ "flags", "structspa__pod__parser__state.html#a88566be69781e492f2927a83429d0d28", null ],
@@ -170,6 +172,8 @@ var group__spa__pod =
       [ "SPA_CHOICE_Enum", "group__spa__pod.html#gga38ee9b093a1a766cfc3d96db7c28067faf6fab992aeab2da08ea1ff556272ce5f", null ],
       [ "SPA_CHOICE_Flags", "group__spa__pod.html#gga38ee9b093a1a766cfc3d96db7c28067fa82fbd414410e306dc9e4cf3a2ac4dc78", null ]
     ] ],
+    [ "SPA_POD_BODY_LOAD_ONCE", "group__spa__pod.html#gab1b8d830aedeabff4720dfd7fd0a8fa6", null ],
+    [ "SPA_POD_BODY_LOAD_FIELD_ONCE", "group__spa__pod.html#ga7c6a1e3f4e10436f330b5e1a625207cd", null ],
     [ "SPA_API_POD_BUILDER", "group__spa__pod.html#gad3fb33e45142e07053b41b31a9d01cd6", null ],
     [ "SPA_POD_BUILDER_FLAG_BODY", "group__spa__pod.html#ga3b0caae7fd8281ebc926bbac640c4f5f", null ],
     [ "SPA_POD_BUILDER_FLAG_FIRST", "group__spa__pod.html#gadc6048dc20a1aa0eb2b4f578b8e63288", null ],
@@ -217,7 +221,9 @@ var group__spa__pod =
     [ "SPA_POD_OBJECT_FOREACH", "group__spa__pod.html#ga506778bb5f4ce87c3416461951633777", null ],
     [ "SPA_POD_SEQUENCE_BODY_FOREACH", "group__spa__pod.html#ga978ad0926ea7b81d8f4e9ebf4208a037", null ],
     [ "SPA_POD_SEQUENCE_FOREACH", "group__spa__pod.html#gafb8085004dbaedb99b30642a18565425", null ],
+    [ "spa_pod_copy_array", "group__spa__pod.html#ga5f2ddae205635e19993eda658c07d583", null ],
     [ "SPA_POD_PARSER_INIT", "group__spa__pod.html#gab0090b49be0a521de62ac22c01096583", null ],
+    [ "SPA_POD_PARSER_COLLECT_BODY", "group__spa__pod.html#ga01c7587e85f717cab5b00f253a3d4f79", null ],
     [ "SPA_POD_PARSER_COLLECT", "group__spa__pod.html#ga79289217b54e0fd108361a43ad6908e8", null ],
     [ "SPA_POD_PARSER_SKIP", "group__spa__pod.html#ga8ef478dc6a1a7ceada9406226d72ce8e", null ],
     [ "SPA_POD_OPT_Bool", "group__spa__pod.html#ga9b47be17366e2b3d3f6c312ba29e6fc7", null ],
@@ -238,10 +244,18 @@ var group__spa__pod =
     [ "SPA_POD_OPT_PodObject", "group__spa__pod.html#ga0fd9ec3343da98a5c2a560d178dbcac1", null ],
     [ "SPA_POD_OPT_PodStruct", "group__spa__pod.html#ga2d61a450e8328ebca28a7ac49850840f", null ],
     [ "SPA_POD_OPT_PodChoice", "group__spa__pod.html#ga1959af59211475212f6e922f292cab02", null ],
+    [ "SPA_POD_OPT_PodBody", "group__spa__pod.html#ga9d1478eb6d468b828ac36fef87b8f31a", null ],
+    [ "SPA_POD_OPT_PodBodyObject", "group__spa__pod.html#ga6836c448fc11441f1c03ead328fcf63d", null ],
+    [ "SPA_POD_OPT_PodBodyStruct", "group__spa__pod.html#ga86ef252d69f6f334907365e2826d09d1", null ],
+    [ "SPA_POD_OPT_PodBodyChoice", "group__spa__pod.html#ga789c85b6b583f3d84d8da20d229cd7ee", null ],
     [ "spa_pod_parser_get_object", "group__spa__pod.html#gac7107618cd0900307bee56d083ff8d91", null ],
     [ "spa_pod_parser_get_struct", "group__spa__pod.html#ga8789019e53e045798845b3c4057ad304", null ],
+    [ "spa_pod_body_parse_object", "group__spa__pod.html#gaa13fcb09e868828cde4b8722836c5c68", null ],
     [ "spa_pod_parse_object", "group__spa__pod.html#gad661885d5748dcaaaa1b7b8ace57697f", null ],
+    [ "spa_pod_body_parse_struct", "group__spa__pod.html#gaa7336ab59ccfc815c42818abd76e6f5f", null ],
     [ "spa_pod_parse_struct", "group__spa__pod.html#gafadfef9f3f4a5295d253339b2b54a3c2", null ],
+    [ "SPA_POD_ALIGN", "group__spa__pod.html#gae897a72e86ef52ad1fc005054b10e369", null ],
+    [ "SPA_POD_MAX_SIZE", "group__spa__pod.html#gad5cca5791b8f078ef5a243d1d7a6757f", null ],
     [ "SPA_POD_BODY_SIZE", "group__spa__pod.html#ga641b2447836ae0dd32a1d8eeb19d611b", null ],
     [ "SPA_POD_TYPE", "group__spa__pod.html#ga555bfc9f09222a6586ad8871378bfbce", null ],
     [ "SPA_POD_SIZE", "group__spa__pod.html#gae7c656416f904f94caf9d4a74f9971eb", null ],
@@ -250,6 +264,9 @@ var group__spa__pod =
     [ "SPA_POD_CONTENTS_CONST", "group__spa__pod.html#ga0588f94569fca38df6c721191b666680", null ],
     [ "SPA_POD_BODY", "group__spa__pod.html#ga5081fb36182775a5c843682e0210d2dc", null ],
     [ "SPA_POD_BODY_CONST", "group__spa__pod.html#ga26c770ca09d2170be9f8fe2725901e03", null ],
+    [ "SPA_POD_IS_VALID", "group__spa__pod.html#ga18851999060faef36df37a73062f5c69", null ],
+    [ "SPA_POD_CHECK_TYPE", "group__spa__pod.html#ga7285347e0f3da3085173b390b462b47d", null ],
+    [ "SPA_POD_CHECK", "group__spa__pod.html#gafc80e8df217638f795aa9a00cd2f950b", null ],
     [ "SPA_POD_VALUE", "group__spa__pod.html#ga360a550f22f66ade502d7662eca14767", null ],
     [ "SPA_POD_ARRAY_CHILD", "group__spa__pod.html#gaa2542f359436bc2d864ddfdd211f77d7", null ],
     [ "SPA_POD_ARRAY_VALUE_TYPE", "group__spa__pod.html#gabb9e7a368ef87910abc4a0856afe0087", null ],
@@ -263,6 +280,8 @@ var group__spa__pod =
     [ "SPA_POD_CHOICE_VALUE_SIZE", "group__spa__pod.html#ga438a8d9d55d42623cf9bf7f1d2a9fdfd", null ],
     [ "SPA_POD_CHOICE_N_VALUES", "group__spa__pod.html#gac9ea5c51626d23ced5b6da1915dde2e8", null ],
     [ "SPA_POD_CHOICE_VALUES", "group__spa__pod.html#ga9eaa0e37a9158469e2cef7aa5f04b04d", null ],
+    [ "SPA_POD_STRUCT_BODY", "group__spa__pod.html#gaa4dd4feb27fa626daad3006e42a7acb1", null ],
+    [ "SPA_POD_STRUCT_BODY_CONST", "group__spa__pod.html#ga7e8047ac0b4ab294bc820fa40a4b52aa", null ],
     [ "SPA_POD_OBJECT_TYPE", "group__spa__pod.html#gab9cf2b5574f4fe4390911f514229b3ee", null ],
     [ "SPA_POD_OBJECT_ID", "group__spa__pod.html#gab9d3422b05af657d6370a6ad789c05a9", null ],
     [ "SPA_POD_PROP_SIZE", "group__spa__pod.html#ga9f6c324e82fc04180ea7d70ce1f8347a", null ],
@@ -271,13 +290,16 @@ var group__spa__pod =
     [ "SPA_POD_PROP_FLAG_HINT_DICT", "group__spa__pod.html#gacc252920ec203fb6a49e82ccb4f80edd", null ],
     [ "SPA_POD_PROP_FLAG_MANDATORY", "group__spa__pod.html#ga3710deebd2fedd9eaf9f9f5e73a3ac01", null ],
     [ "SPA_POD_PROP_FLAG_DONT_FIXATE", "group__spa__pod.html#ga765ef8a7efa487db110ec67c998ff2ea", null ],
+    [ "SPA_POD_PROP_FLAG_DROP", "group__spa__pod.html#ga49edea2b84da0cb3e0c334cf929e6aee", null ],
     [ "SPA_POD_CONTROL_SIZE", "group__spa__pod.html#ga9189a4c2f9bf8f7022e6f98c9b24ebfe", null ],
     [ "SPA_POD_Prop", "group__spa__pod.html#ga889dbb7e4f3b0ff6f885d26398e87c4c", null ],
+    [ "SPA_POD_Propf", "group__spa__pod.html#gab5a11d91ff73d57d908f734fc9e5d611", null ],
     [ "SPA_POD_Control", "group__spa__pod.html#ga2313f26833e446d185bdb0600a45fb8f", null ],
     [ "SPA_CHOICE_RANGE", "group__spa__pod.html#ga144704206888a0e6405790fd694fa296", null ],
     [ "SPA_CHOICE_STEP", "group__spa__pod.html#ga92ea46020be2f82c651369d76c9e137a", null ],
-    [ "SPA_CHOICE_ENUM", "group__spa__pod.html#gadd96b34a074f0a4065ae1e3d055ef99f", null ],
+    [ "SPA_CHOICE_ENUM", "group__spa__pod.html#gac23ba1e7693275d6f2fc705930684766", null ],
     [ "SPA_CHOICE_FLAGS", "group__spa__pod.html#ga26823c0f7c08a7b361451575493c6c9c", null ],
+    [ "SPA_CHOICE_FEATURES", "group__spa__pod.html#ga77dd919b991af7d16a62d8af5a515dcb", null ],
     [ "SPA_CHOICE_BOOL", "group__spa__pod.html#ga80c22ac336bb35f14a3692372f13c01f", null ],
     [ "SPA_POD_Bool", "group__spa__pod.html#ga10cb92b7996b3ed2b31295fc52bb83f9", null ],
     [ "SPA_POD_CHOICE_Bool", "group__spa__pod.html#ga77acabfebad965007133387bed64922d", null ],
@@ -288,11 +310,13 @@ var group__spa__pod =
     [ "SPA_POD_CHOICE_RANGE_Int", "group__spa__pod.html#ga57b2b5bc72e7fbf6c78cfd5d601ad855", null ],
     [ "SPA_POD_CHOICE_STEP_Int", "group__spa__pod.html#ga6432e0723995e1dec2b9ae6b76a6bd91", null ],
     [ "SPA_POD_CHOICE_FLAGS_Int", "group__spa__pod.html#gaea71c973cc38a58e1efd3ab257278d72", null ],
+    [ "SPA_POD_CHOICE_FEATURES_Int", "group__spa__pod.html#ga3dc2323c8b97b27ae2a1be3ffddb1c34", null ],
     [ "SPA_POD_Long", "group__spa__pod.html#ga2fb7171ab4bf8b85b835c8ac66cc3a26", null ],
     [ "SPA_POD_CHOICE_ENUM_Long", "group__spa__pod.html#ga7a44d36fbdc823dc9befeccad3429635", null ],
     [ "SPA_POD_CHOICE_RANGE_Long", "group__spa__pod.html#ga00e180f5c166a1ab73d13357244e5eef", null ],
     [ "SPA_POD_CHOICE_STEP_Long", "group__spa__pod.html#ga95b23f18f2136eee0eb6e9c8446caa7a", null ],
     [ "SPA_POD_CHOICE_FLAGS_Long", "group__spa__pod.html#ga13bd8184344389ed4e4007872286ae81", null ],
+    [ "SPA_POD_CHOICE_FEATURES_LONG", "group__spa__pod.html#gab12dcaec576b5a103c1755b7eeb1116e", null ],
     [ "SPA_POD_Float", "group__spa__pod.html#gaa5ae3c08bb5f3e90e5b0688c5668e002", null ],
     [ "SPA_POD_CHOICE_ENUM_Float", "group__spa__pod.html#ga697129f8c015770ec03468adf9127705", null ],
     [ "SPA_POD_CHOICE_RANGE_Float", "group__spa__pod.html#ga0f55c34f22f68b723fca4a416841b247", null ],
@@ -320,17 +344,68 @@ var group__spa__pod =
     [ "SPA_POD_PodObject", "group__spa__pod.html#gaa0db41ba0cc387086b23f9d1cf743b93", null ],
     [ "SPA_POD_PodStruct", "group__spa__pod.html#gae0e9d191c91c8a70852a875dda2a06b6", null ],
     [ "SPA_POD_PodChoice", "group__spa__pod.html#ga6acb5a42673d597a7a03f2c2a056e053", null ],
+    [ "SPA_POD_PodBody", "group__spa__pod.html#ga495db027b256f012dac4101651285a89", null ],
+    [ "SPA_POD_PodBodyObject", "group__spa__pod.html#ga5bd31cc427786c2032fda0363394616a", null ],
+    [ "SPA_POD_PodBodyStruct", "group__spa__pod.html#ga1d97d6d9e784be13b54bc561e2edd0fb", null ],
+    [ "SPA_POD_PodBodyChoice", "group__spa__pod.html#gafd854b78f48d8f19c5cdacce29515778", null ],
+    [ "spa_pod_type_size", "group__spa__pod.html#ga739599f01109717ee2f10147e4cb7450", null ],
+    [ "spa_pod_choice_n_values", "group__spa__pod.html#ga52506068f95a4edb14f856c7d8ecb237", null ],
+    [ "spa_pod_body_from_data", "group__spa__pod.html#gae776a378f4f40d9010ff1b7722548e80", null ],
+    [ "spa_pod_is_none", "group__spa__pod.html#ga4cfc861aa51bd2423ba07a01df8bfada", null ],
+    [ "spa_pod_is_bool", "group__spa__pod.html#ga5e581695adfb7b3b46d9300aedf79785", null ],
+    [ "spa_pod_body_get_bool", "group__spa__pod.html#gabc1ebfa4879fdce8bf2a4239abf83f61", null ],
+    [ "spa_pod_is_id", "group__spa__pod.html#ga7371be05c91ca4627e4409dafbb50b27", null ],
+    [ "spa_pod_body_get_id", "group__spa__pod.html#gaf2d06b9449aabc6cd975205521e68e7b", null ],
+    [ "spa_pod_is_int", "group__spa__pod.html#ga433ccd467720dee6b9b6f33ffe78702a", null ],
+    [ "spa_pod_body_get_int", "group__spa__pod.html#gaaa385e0ec1f3f006f2944d5b133c9b86", null ],
+    [ "spa_pod_is_long", "group__spa__pod.html#gafcd42019e755d8b45b627872f3a97e87", null ],
+    [ "spa_pod_body_get_long", "group__spa__pod.html#gaa198f65036b3442e46beb64c03f4b5e4", null ],
+    [ "spa_pod_is_float", "group__spa__pod.html#gaf83ebb1ba094e95d55d3dd3994971d69", null ],
+    [ "spa_pod_body_get_float", "group__spa__pod.html#gab8eff5f9ee441a5499a11e199a1557c8", null ],
+    [ "spa_pod_is_double", "group__spa__pod.html#ga2affa49009304a543f13955aa07a00fd", null ],
+    [ "spa_pod_body_get_double", "group__spa__pod.html#ga85a0b109b7c6ab65562c85d3f8fd3dcf", null ],
+    [ "spa_pod_is_string", "group__spa__pod.html#gaaf63fa3de4c3ba84741b923cb4f4e948", null ],
+    [ "spa_pod_body_get_string", "group__spa__pod.html#ga31a5e6affadff94b02dc00c9f72d4f3d", null ],
+    [ "spa_pod_body_copy_string", "group__spa__pod.html#ga9a2ee9c53d772e92f9eae6ec431e36f2", null ],
+    [ "spa_pod_is_bytes", "group__spa__pod.html#gaa9191db0182abc73ad25d44041724e40", null ],
+    [ "spa_pod_body_get_bytes", "group__spa__pod.html#gafbd9c52e25e9f6972566addc759cbf99", null ],
+    [ "spa_pod_is_pointer", "group__spa__pod.html#ga10249ee36e399d5e11b581e10038444a", null ],
+    [ "spa_pod_body_get_pointer", "group__spa__pod.html#ga1ed5fe5df2bbaeef92aeafe599a3cb27", null ],
+    [ "spa_pod_is_fd", "group__spa__pod.html#ga4683cb8cefe8feba8afde945efa91962", null ],
+    [ "spa_pod_body_get_fd", "group__spa__pod.html#gaee7f47fed4189ade60fe3e9c81967d21", null ],
+    [ "spa_pod_is_rectangle", "group__spa__pod.html#ga364670be1af8217628212ad5082c37b7", null ],
+    [ "spa_pod_body_get_rectangle", "group__spa__pod.html#gabbb83fa91dc6463ad5cce364cc47bdf0", null ],
+    [ "spa_pod_is_fraction", "group__spa__pod.html#ga18efc93b9b6bec1df0cc3f3af3385557", null ],
+    [ "spa_pod_body_get_fraction", "group__spa__pod.html#ga481d3be6005460f37cc094f4b4e64119", null ],
+    [ "spa_pod_is_bitmap", "group__spa__pod.html#ga124e624c658f04f6c19326cb5c24cc96", null ],
+    [ "spa_pod_body_get_bitmap", "group__spa__pod.html#gacad17cd970ae527714c558819cfc139b", null ],
+    [ "spa_pod_is_array", "group__spa__pod.html#ga35c1c942cbee7c1504bba34c31fc6b89", null ],
+    [ "spa_pod_body_get_array", "group__spa__pod.html#ga7c98698dc0b0e599ec81538a78522963", null ],
+    [ "spa_pod_array_body_get_values", "group__spa__pod.html#ga582fb9a481313638185ce6f158eda737", null ],
+    [ "spa_pod_body_get_array_values", "group__spa__pod.html#ga2e89e8ed4e7c6a3470d1a20f256d1e78", null ],
+    [ "spa_pod_is_choice", "group__spa__pod.html#gaefd33ea6899c1048a35da2d698925cde", null ],
+    [ "spa_pod_body_get_choice", "group__spa__pod.html#gaea7cec7fc017578e4235f9193fa12151", null ],
+    [ "spa_pod_choice_body_get_values", "group__spa__pod.html#gaa6e71343c54da71718a18a79645965b3", null ],
+    [ "spa_pod_is_struct", "group__spa__pod.html#ga3bdd866aa603a05e6b75ecc00b8b9897", null ],
+    [ "spa_pod_is_object", "group__spa__pod.html#ga57d565102dce8f2349e0d8fd71849a38", null ],
+    [ "spa_pod_body_get_object", "group__spa__pod.html#gaa23e20ca07254a83e0ec48aef45952bb", null ],
+    [ "spa_pod_is_sequence", "group__spa__pod.html#ga07a69f74c385c8b59badf0217e4563d1", null ],
+    [ "spa_pod_body_get_sequence", "group__spa__pod.html#ga309c83afb1bc710e1785179eac0bdf68", null ],
     [ "spa_pod_builder_get_state", "group__spa__pod.html#ga4795769ae18a47327b7539346a4fb98f", null ],
+    [ "spa_pod_builder_corrupted", "group__spa__pod.html#ga053b0321bd7c1510ff945698a98b5866", null ],
     [ "spa_pod_builder_set_callbacks", "group__spa__pod.html#gaf3c98d7eb05d0701fabbb3d9d2c2a574", null ],
     [ "spa_pod_builder_reset", "group__spa__pod.html#ga7e6fc23f7cf1b70ad444f67efe759e7f", null ],
     [ "spa_pod_builder_init", "group__spa__pod.html#ga7dd63a811aad707837031ee78daf68e0", null ],
+    [ "spa_pod_builder_deref_fallback", "group__spa__pod.html#gafb78b085b27e12b7717b224b5cd36ad5", null ],
     [ "spa_pod_builder_deref", "group__spa__pod.html#ga61143b88eb74b91f689eb04fe2cce9d1", null ],
     [ "spa_pod_builder_frame", "group__spa__pod.html#gac177ad06ec7d77726dca991055119c5e", null ],
     [ "spa_pod_builder_push", "group__spa__pod.html#ga9838aef3fb190cc3b22721f098aa6516", null ],
     [ "spa_pod_builder_raw", "group__spa__pod.html#gabcd9bb70c3fa67e1545aee28d792d2df", null ],
+    [ "spa_pod_builder_remove", "group__spa__pod.html#ga7678877a625af7c56a797c9d4151be19", null ],
     [ "spa_pod_builder_pad", "group__spa__pod.html#ga15a759659fddcb40af2213cb168f142f", null ],
     [ "spa_pod_builder_raw_padded", "group__spa__pod.html#gacc4854f685124c211f4309519c4ceb5a", null ],
     [ "spa_pod_builder_pop", "group__spa__pod.html#ga046da888a04438116c067d149235d9d7", null ],
+    [ "spa_pod_builder_primitive_body", "group__spa__pod.html#gaa3388f3b62b8ed12923a6a79271be1b7", null ],
     [ "spa_pod_builder_primitive", "group__spa__pod.html#gacbce6842b68cde22775e2887631d1900", null ],
     [ "spa_pod_builder_none", "group__spa__pod.html#ga21d3ea31e47e2c3e2a1f8e7cd2fdbd63", null ],
     [ "spa_pod_builder_child", "group__spa__pod.html#ga2dd63b5e1306b340295c91f740874a95", null ],
@@ -345,9 +420,6 @@ var group__spa__pod =
     [ "spa_pod_builder_string", "group__spa__pod.html#ga2612ff1c5a0de44d98493019f0de88f4", null ],
     [ "spa_pod_builder_bytes", "group__spa__pod.html#ga881e7392e10a4a76c8ffd6949ac91f28", null ],
     [ "spa_pod_builder_reserve_bytes", "group__spa__pod.html#gac58d805740cffcc624637f33c9ce531f", null ],
-    [ "spa_pod_builder_bytes_start", "group__spa__pod.html#gaa371f89c434d5b2372cb8203bc75bc6d", null ],
-    [ "spa_pod_builder_bytes_append", "group__spa__pod.html#ga4e5213600b18c9cec008ae4f0a0cc90b", null ],
-    [ "spa_pod_builder_bytes_end", "group__spa__pod.html#ga5359133db94a96f7c64dbe1abcca04b8", null ],
     [ "spa_pod_builder_pointer", "group__spa__pod.html#ga430fe770e51e8cd15ba95da237f33848", null ],
     [ "spa_pod_builder_fd", "group__spa__pod.html#ga415646149c8f67137ee7d6b8badd8446", null ],
     [ "spa_pod_builder_rectangle", "group__spa__pod.html#ga6e652264307f46d24cd7c986874a41ed", null ],
@@ -360,18 +432,24 @@ var group__spa__pod =
     [ "spa_pod_builder_prop", "group__spa__pod.html#gaf873ff5065718c4b260f64c5fce1cf1f", null ],
     [ "spa_pod_builder_push_sequence", "group__spa__pod.html#gac14983b53b32aeb6bf3797d808a65f73", null ],
     [ "spa_pod_builder_control", "group__spa__pod.html#ga57e0acda7dc7525adbe7dea11311f3d6", null ],
+    [ "spa_choice_from_id_flags", "group__spa__pod.html#ga24a9101fcd549d77a4bba589291c3397", null ],
     [ "spa_choice_from_id", "group__spa__pod.html#ga9a69624bdd69e3a0a4dbe8c01852bfcb", null ],
     [ "spa_pod_builder_addv", "group__spa__pod.html#ga775b5a9648ac5d3ff8d6b5098057c752", null ],
     [ "spa_pod_builder_add", "group__spa__pod.html#ga5cfb06a3cbb14a0c2f9bb1c730e7ef47", null ],
     [ "spa_pod_copy", "group__spa__pod.html#ga86925b11f4350230b0b32e722af734cf", null ],
     [ "spa_pod_compare_value", "group__spa__pod.html#ga500eb3542177d43057f1aded0b565edf", null ],
+    [ "spa_pod_memcmp", "group__spa__pod.html#gaea992e584577b8b2f6987e746250e425", null ],
     [ "spa_pod_compare", "group__spa__pod.html#ga28626951bcacce86bd5e795f78579df3", null ],
-    [ "spa_pod_choice_fix_default", "group__spa__pod.html#gabc558ddd3d0bf9349a1475bebfb21350", null ],
-    [ "spa_pod_filter_flags_value", "group__spa__pod.html#gaa0c2df9d68269915d799791c2307bf55", null ],
-    [ "spa_pod_filter_is_step_of", "group__spa__pod.html#gad3ae9092ec6f5a906c12092fbc00648d", null ],
+    [ "spa_pod_compare_is_compatible_flags", "group__spa__pod.html#ga7011e6d0f949eb6c3e3acf2e032225e9", null ],
+    [ "spa_pod_compare_is_step_of", "group__spa__pod.html#ga19a1fee8a2cf9f760bda31c6f51dcd90", null ],
+    [ "spa_pod_compare_is_in_range", "group__spa__pod.html#ga16bdf93629c365a4d6fa3fb9a0cd3f97", null ],
+    [ "spa_pod_compare_is_valid_choice", "group__spa__pod.html#ga39439c955471eb5e20db36b47d344866", null ],
+    [ "spa_pod_filter_flags_value", "group__spa__pod.html#ga366f6e45061295907527cc45d8b619b8", null ],
     [ "spa_pod_filter_prop", "group__spa__pod.html#ga469ec38ab970b01f4b9309affdcdae27", null ],
     [ "spa_pod_filter_part", "group__spa__pod.html#gae7c390ecf2f7cd9fd1446de49de762c3", null ],
     [ "spa_pod_filter", "group__spa__pod.html#ga77d54105688277dd64a9926b724a2e56", null ],
+    [ "spa_pod_filter_object_make", "group__spa__pod.html#gac565836650a9aa9c800abdf3838b6cfd", null ],
+    [ "spa_pod_filter_make", "group__spa__pod.html#ga5c085daf5d366a351367972a9e770d81", null ],
     [ "spa_pod_is_inside", "group__spa__pod.html#gab89299e55c35e4a060d207ccfbbcd7b9", null ],
     [ "spa_pod_next", "group__spa__pod.html#ga5850d793dcf7d300dd3c47682c9a5b70", null ],
     [ "spa_pod_prop_first", "group__spa__pod.html#ga0fc03bd3c21656ce4138fdb37fe3e6fc", null ],
@@ -381,60 +459,50 @@ var group__spa__pod =
     [ "spa_pod_control_is_inside", "group__spa__pod.html#ga073c04fac1b3bace67b74dd9bba72e70", null ],
     [ "spa_pod_control_next", "group__spa__pod.html#ga310089983cd8391ed7bd0bf623938c81", null ],
     [ "spa_pod_from_data", "group__spa__pod.html#ga1a65f6318a9c5f7f1989f0add721491d", null ],
-    [ "spa_pod_is_none", "group__spa__pod.html#ga60183328451e626b279017bfdc4d0ec3", null ],
-    [ "spa_pod_is_bool", "group__spa__pod.html#gab6ede19044b0ff1a025d3defccc31e03", null ],
     [ "spa_pod_get_bool", "group__spa__pod.html#ga75c9298fa8ecd38207e948374ab455f5", null ],
-    [ "spa_pod_is_id", "group__spa__pod.html#ga4f279e90868e1aa8e894bd0b91073665", null ],
     [ "spa_pod_get_id", "group__spa__pod.html#ga4009e179eeaad8c1bcac94c394182834", null ],
-    [ "spa_pod_is_int", "group__spa__pod.html#ga152321b930509598c1a3e51d4a594953", null ],
     [ "spa_pod_get_int", "group__spa__pod.html#ga0d68d76f3a4a7f8a921874001e8e8c56", null ],
-    [ "spa_pod_is_long", "group__spa__pod.html#ga060ddf72b95820032fbbcff969df3b9d", null ],
     [ "spa_pod_get_long", "group__spa__pod.html#ga6c03061c7c47898b03e20152aa784a91", null ],
-    [ "spa_pod_is_float", "group__spa__pod.html#ga4d92073f64ccd86631bcbc46c576adac", null ],
     [ "spa_pod_get_float", "group__spa__pod.html#ga705717f9fb155c098df1db55eb6735d3", null ],
-    [ "spa_pod_is_double", "group__spa__pod.html#gae83c72c738e7e39fa2a47a7d68b5028c", null ],
     [ "spa_pod_get_double", "group__spa__pod.html#ga8ded21dcd0d583e3fe8c13f75b4faf6d", null ],
-    [ "spa_pod_is_string", "group__spa__pod.html#gaa41cbed701e89c003ac1f369a7424011", null ],
     [ "spa_pod_get_string", "group__spa__pod.html#gad2c94d86d5effc6329d51ab76c117351", null ],
     [ "spa_pod_copy_string", "group__spa__pod.html#ga9faea3d69dc09fbc55b3aa58ea701a9b", null ],
-    [ "spa_pod_is_bytes", "group__spa__pod.html#gae5e8beb437c39ab932a4508f3c07f87e", null ],
     [ "spa_pod_get_bytes", "group__spa__pod.html#ga47682279ff84554d1d2ff5afea50cd3e", null ],
-    [ "spa_pod_is_pointer", "group__spa__pod.html#ga599b7614b3fe98e47bb787625d6af192", null ],
     [ "spa_pod_get_pointer", "group__spa__pod.html#ga3c501698ac0240cf1575c5d2ee007fef", null ],
-    [ "spa_pod_is_fd", "group__spa__pod.html#ga9c56e51c2c0f50b4043550ef14e82ee2", null ],
     [ "spa_pod_get_fd", "group__spa__pod.html#ga5f16d4b0a97ed59a8bfd07ede91f0f6e", null ],
-    [ "spa_pod_is_rectangle", "group__spa__pod.html#gaf99693434fae39e39505a092ff5a329c", null ],
     [ "spa_pod_get_rectangle", "group__spa__pod.html#ga8b93d6023c0f82a28bddc830a5447315", null ],
-    [ "spa_pod_is_fraction", "group__spa__pod.html#ga15a104f9e06bc857ddfaf9e2fed5c91e", null ],
     [ "spa_pod_get_fraction", "group__spa__pod.html#gaef4fda20115f2af434d5436bab052ac6", null ],
-    [ "spa_pod_is_bitmap", "group__spa__pod.html#gab853c727390ca876b3b14e2ae136eb3d", null ],
-    [ "spa_pod_is_array", "group__spa__pod.html#gaf83d49c52841bde42a5cb9a6598fd4c7", null ],
+    [ "spa_pod_get_array_full", "group__spa__pod.html#ga6b743942696a57323536deee721691a9", null ],
     [ "spa_pod_get_array", "group__spa__pod.html#gaeef696992e024a586efb11648dc9971c", null ],
-    [ "spa_pod_copy_array", "group__spa__pod.html#ga7b773b02db1f5f988836706859cf5223", null ],
-    [ "spa_pod_is_choice", "group__spa__pod.html#ga3fec7693667fe7163c2462a5d58e28a4", null ],
+    [ "spa_pod_copy_array_full", "group__spa__pod.html#gac80b1ad02aaa3ff976c8eebe7a555bca", null ],
     [ "spa_pod_get_values", "group__spa__pod.html#ga2ec87a5b5863e9b1978ae5ce0dca4b1c", null ],
-    [ "spa_pod_is_struct", "group__spa__pod.html#ga9a0e177f25915db5337798bc8597148b", null ],
-    [ "spa_pod_is_object", "group__spa__pod.html#ga7dbb642efbf4df41c04d089c44d542a4", null ],
     [ "spa_pod_is_object_type", "group__spa__pod.html#gacfd1f7f82d6d0abc12efb4dc20fa34fa", null ],
     [ "spa_pod_is_object_id", "group__spa__pod.html#gab26c4649c98d4fe32acfb18204537dbe", null ],
-    [ "spa_pod_is_sequence", "group__spa__pod.html#gaaf2417a51f87097b3c74b91dfc86b2ab", null ],
     [ "spa_pod_object_find_prop", "group__spa__pod.html#ga4f4ec480d67935dd9cae4c08d24fe227", null ],
     [ "spa_pod_find_prop", "group__spa__pod.html#ga2e3f6d030ab0f8ca98819b954f469056", null ],
-    [ "spa_pod_object_fixate", "group__spa__pod.html#ga5032974958e8f4cdcc53bedd93c0d38e", null ],
-    [ "spa_pod_fixate", "group__spa__pod.html#ga9ce6665c76cad526a5e17e3ddfa58fe7", null ],
-    [ "spa_pod_object_is_fixated", "group__spa__pod.html#gad145c153f21a6d550ffc648803dfe715", null ],
     [ "spa_pod_object_has_props", "group__spa__pod.html#gaf74c1a23d620f127ac14b740f5bf5615", null ],
+    [ "spa_pod_object_fixate", "group__spa__pod.html#ga5032974958e8f4cdcc53bedd93c0d38e", null ],
+    [ "spa_pod_object_is_fixated", "group__spa__pod.html#gad145c153f21a6d550ffc648803dfe715", null ],
+    [ "spa_pod_fixate", "group__spa__pod.html#ga9ce6665c76cad526a5e17e3ddfa58fe7", null ],
     [ "spa_pod_is_fixated", "group__spa__pod.html#ga88c8e24da5a4b626f061c90a027beae1", null ],
     [ "spa_pod_parser_init", "group__spa__pod.html#gac71cd915e95b3be18b7ca4635fd1f7be", null ],
     [ "spa_pod_parser_pod", "group__spa__pod.html#ga1a80b7aedc0934fe9c5e1ec023ee418f", null ],
+    [ "spa_pod_parser_init_pod_body", "group__spa__pod.html#ga4146c1e5c83bb12942bc4f0e505bbc0d", null ],
+    [ "spa_pod_parser_init_from_data", "group__spa__pod.html#ga024f75f82e5f3801fe4166149b894a9c", null ],
     [ "spa_pod_parser_get_state", "group__spa__pod.html#gaa87b95f37453216f6c11a1bd2196e58d", null ],
     [ "spa_pod_parser_reset", "group__spa__pod.html#ga538bdcdd8416d5f18a34340322dd6a8d", null ],
+    [ "spa_pod_parser_read_header", "group__spa__pod.html#ga58e943f15ec5df18fdda849e5e9598ee", null ],
     [ "spa_pod_parser_deref", "group__spa__pod.html#ga160af2517946c5b77f2a232a78292281", null ],
     [ "spa_pod_parser_frame", "group__spa__pod.html#ga9b557f0ab075d538f9b63196a18b93f2", null ],
     [ "spa_pod_parser_push", "group__spa__pod.html#ga01671c80c9a0204dbefd46f8da946257", null ],
+    [ "spa_pod_parser_get_header", "group__spa__pod.html#gab430991a006f39d433daebe30c59e5d5", null ],
+    [ "spa_pod_parser_current_body", "group__spa__pod.html#gab2e89b5fa44c86ead467e4ce25957ba9", null ],
     [ "spa_pod_parser_current", "group__spa__pod.html#ga21fcc2025afc8316dffc3133dfa10528", null ],
     [ "spa_pod_parser_advance", "group__spa__pod.html#ga455ca5d254c73ee229d5b609af0ec29f", null ],
+    [ "spa_pod_parser_next_body", "group__spa__pod.html#ga49ceea8494e07627d37e54423f683e05", null ],
     [ "spa_pod_parser_next", "group__spa__pod.html#ga1cbbdc23cb5d3d59c9daadcd611f4ac8", null ],
+    [ "spa_pod_parser_restart", "group__spa__pod.html#gaf92153e36572039dace885b0263114d0", null ],
+    [ "spa_pod_parser_unpush", "group__spa__pod.html#ga7584bab011c82b9ebab0ce69d528d435", null ],
     [ "spa_pod_parser_pop", "group__spa__pod.html#ga1269955ce51dbbb0a99c6f47d047beb8", null ],
     [ "spa_pod_parser_get_bool", "group__spa__pod.html#ga79cac7629b184a87d9d37c4f543c9575", null ],
     [ "spa_pod_parser_get_id", "group__spa__pod.html#gaec141928bafc63c6fc3d482e4e4958c3", null ],
@@ -448,10 +516,23 @@ var group__spa__pod =
     [ "spa_pod_parser_get_fd", "group__spa__pod.html#ga7580be61c834af3f3faa6ed5c1e5b7d5", null ],
     [ "spa_pod_parser_get_rectangle", "group__spa__pod.html#gad8fa8a75e7c4f6aed672baef991685e9", null ],
     [ "spa_pod_parser_get_fraction", "group__spa__pod.html#ga370908e59ae7509103f20f8bcc58b8ac", null ],
+    [ "spa_pod_parser_get_pod_body", "group__spa__pod.html#gad7e3014c757b9883bcee062c504392c3", null ],
     [ "spa_pod_parser_get_pod", "group__spa__pod.html#ga80145929661a13f9c2e7477b9a01df76", null ],
+    [ "spa_pod_parser_init_struct_body", "group__spa__pod.html#ga0c86848a045062e77c657d8571804063", null ],
+    [ "spa_pod_parser_push_struct_body", "group__spa__pod.html#gae1f0bfb45d9195df992fbdcd5b58aeb2", null ],
     [ "spa_pod_parser_push_struct", "group__spa__pod.html#ga801596f87a5e0070a22728d2d30ad2c8", null ],
+    [ "spa_pod_parser_init_object_body", "group__spa__pod.html#ga4ef0f6d94abdaa5fb9fcc911861762a1", null ],
+    [ "spa_pod_parser_push_object_body", "group__spa__pod.html#ga78bbe8c8c694b407a07fd574dc1e2c87", null ],
     [ "spa_pod_parser_push_object", "group__spa__pod.html#ga5a85c18ddf3ea24e3566605108032b2f", null ],
+    [ "spa_pod_parser_get_prop_body", "group__spa__pod.html#ga56c6326eef147fdd1e0d11f441f749e7", null ],
+    [ "spa_pod_parser_push_sequence_body", "group__spa__pod.html#ga23fd61673f7629cc8b9d6779adfa413f", null ],
+    [ "spa_pod_parser_get_control_body", "group__spa__pod.html#ga3330005c218d0f6130a074288fd1dfe1", null ],
+    [ "spa_pod_parser_object_find_prop", "group__spa__pod.html#ga5f104125b5fd6ee3ffa1d366f76a142e", null ],
+    [ "spa_pod_parser_body_can_collect", "group__spa__pod.html#ga294260666d98752b3fa96b58b1aeb4cc", null ],
     [ "spa_pod_parser_can_collect", "group__spa__pod.html#ga73d5b0fff8a30da094c73d3f3fd08177", null ],
     [ "spa_pod_parser_getv", "group__spa__pod.html#ga585e95f3fb9e7825df8720cf18c338b8", null ],
-    [ "spa_pod_parser_get", "group__spa__pod.html#gab87969eef48e78bd1206663cac7ed2ef", null ]
+    [ "spa_pod_parser_get", "group__spa__pod.html#gab87969eef48e78bd1206663cac7ed2ef", null ],
+    [ "spa_pod_simplify_merge", "group__spa__pod.html#ga23a4133518cb7d4473db7c56d6888d10", null ],
+    [ "spa_pod_simplify_struct", "group__spa__pod.html#gad4aba7e06b7c0e5bf358b4b652b8b4e3", null ],
+    [ "spa_pod_simplify", "group__spa__pod.html#ga8266e8a6dec1b09ac79634d314884076", null ]
 ];
\ No newline at end of file
