@@ -1,6 +1,6 @@
 var searchData=
 [
-  ['names_0',['Names',['../group__spa__names.html',1,'Factory Names'],['../group__spa__keys.html',1,'Key Names'],['../group__pw__keys.html',1,'Key Names']]],
+  ['names_0',['Names',['../group__pw__capabilities.html',1,'Capability Names'],['../group__spa__names.html',1,'Factory Names'],['../group__spa__keys.html',1,'Key Names'],['../group__pw__keys.html',1,'Key Names']]],
   ['native_20protocol_1',['Native Protocol',['../group__pw__protocol__native.html',1,'']]],
   ['node_2',['Node',['../group__pw__client__node.html',1,'Client Node'],['../group__pw__node.html',1,'Node'],['../group__spa__node.html',1,'Node']]],
   ['node_20impl_3',['Node Impl',['../group__pw__impl__node.html',1,'']]]
