@@ -1,6 +1,6 @@
 var indexSectionsWithContent =
 {
-  0: "123456_abcdefghijklmnopqrstuvwxyz",
+  0: "1234567_abcdefghijklmnopqrstuvwxyz",
   1: "ips",
   2: "abcdefghijklmnoprstuvw",
   3: "psv",
@@ -10,7 +10,7 @@ var indexSectionsWithContent =
   7: "_ps",
   8: "_eps",
   9: "abcdefghijklmnpqrstuw",
-  10: "123456abcdefghijlmnoprstuvxz"
+  10: "1234567abcdefghijlmnoprstuvwxz"
 };
 
 var indexSectionNames =
